<h2>BRIEF:</h2>
<p>This package finds the exponent of a value with respect to a given degree</p>

<h1>HOW TO USE </h1>:
<p>------> call the funtion : ex(value,degree)</p>
<p>------> NB: value and degree arguments are expeced to be integers</p>

<h2>EXAMPLE:</h2>
<p>from exponema import expon</p>
<p>expon.ex(2,3)</p>
<p>### result 8 </p>
